#ifndef _cpuinfo_h
#define _cpuinfo_h


struct Cpuinfo
{
  int cpus;
  float speedmhz;
};


#endif // _cpuinfo_h
